@@ -129,10 +129,10 @@ check.pltcnt <- function(pltx, puniqueid=NULL, unitlut, unitvars=NULL,
 
   if (showwarnings && any(pltcnt$errtyp == "warn")) {
 
-    msg <- "## warnings/errors.."
+    msg <- "## warnings/errors"
     message("\n################################### \n",
             msg, "\n###################################")
-    message(paste0(capture.output(pltcnt), collapse = "\n"))
+    message(paste0(capture.output(data.frame(pltcnt)), collapse = "\n"))
 
     if (stopiferror && any(errtab[["errtyp"]] == "warn")) {
       stop("not enough plots in strata")
