@@ -8,7 +8,7 @@
 #' \tabular{llll}{ \tab \bold{Data} 
 #' \tab \bold{Variable} \tab \bold{Description}\cr 
 #' \tab cond \tab cuniqueid \tab Unique identifier for each plot, to link to pltassgn (ex. PLT_CN).\cr \tab
-#' \tab CONDID \tab Unique identfier of each condition on plot.  Set CONDID=1,
+#' \tab CONDID \tab Unique identifier of each condition on plot.  Set CONDID=1,
 #' if only 1 condition per plot.\cr 
 #' \tab \tab CONDPROP_UNADJ \tab Unadjusted proportion of condition on each plot. Set CONDPROP_UNADJ=1, if only 1
 #' condition per plot.\cr 
@@ -255,7 +255,7 @@ modWFarea <- function(WFpopdat,
   nonresp <- TRUE
 
   ## Set global variables
-  ONEUNIT=n.total=n.strata=strwt=TOTAL=rowvar.filter=colvar.filter=
+  ONEUNIT=n.total=n.strata=strwt=TOTAL=
     rawfolder=n.resp=n.nonresp=SUBPPROP_UNADJ=pmeasprop <- NULL
   #estvar <- "CONDPROP_ADJ"
   
@@ -434,8 +434,7 @@ modWFarea <- function(WFpopdat,
   ###################################################################################
   rowcolinfo <- check.rowcol(gui=gui, esttype=esttype, 
                   condf=pltcondf, cuniqueid=cuniqueid, 
-                  rowvar=rowvar, rowvar.filter=rowvar.filter, 
-                  colvar=colvar, colvar.filter=colvar.filter, 
+                  rowvar=rowvar, colvar=colvar, 
                   row.FIAname=row.FIAname, col.FIAname=col.FIAname, 
                   row.orderby=row.orderby, col.orderby=col.orderby, 
                   row.add0=row.add0, col.add0=col.add0, 
