@@ -13,7 +13,7 @@
 #' TPA_UNADJ=6.018046 for trees on subplot; 74.965282 for trees on
 #' microplot).\cr \tab cond \tab cuniqueid \tab Unique identifier for each
 #' plot, to link to pltassgn (ex. PLT_CN).\cr \tab \tab CONDID \tab Unique
-#' identfier of each condition on plot.  Set CONDID=1, if only 1 condition per
+#' identifier of each condition on plot.  Set CONDID=1, if only 1 condition per
 #' plot.\cr \tab \tab CONDPROP_UNADJ \tab Unadjusted proportion of condition on
 #' each plot.  Set CONDPROP_UNADJ=1, if only 1 condition per plot.\cr \tab \tab
 #' COND_STATUS_CD \tab Status of each forested condition on plot (i.e.
@@ -45,6 +45,10 @@
 #' syntax (e.g., 'STATUSCD == 1').
 #' @param estseed String. Use seedling data only or add to tree data. Seedling
 #' estimates are only for counts (estvar='TPA_UNADJ')-('none', 'only', 'add').
+#' @param woodland String. If woodland = 'Y', include woodland tree species  
+#' where measured. If woodland = 'N', only include timber species. See 
+#' FIESTA::ref_species$WOODLAND ='Y/N'. If woodland = 'only', only include
+#' woodland species.
 #' @param landarea String. The condition-level filter for defining land area
 #' ('ALL', 'FOREST', 'TIMBERLAND'). If landarea='FOREST', COND_STATUS_CD = 1;
 #' if landarea='TIMBERLAND', SITECLCD in(1:6) & RESERVCD = 0.
@@ -231,6 +235,7 @@ modWFtree <- function(WFpopdat,
                       estvar, 
                       estvar.filter=NULL, 
                       estseed="none", 
+					  woodland = "Y",
                       landarea="FOREST", 
                       pcfilter=NULL, 
                       rowvar=NULL, 
@@ -270,7 +275,7 @@ modWFtree <- function(WFpopdat,
   nonresp <- TRUE 
   
   ## Set global variables
-  ONEUNIT=n.total=n.strata=strwt=TOTAL=rowvar.filter=colvar.filter=
+  ONEUNIT=n.total=n.strata=strwt=TOTAL=
 	n.resp=n.nonresp=SUBPPROP_UNADJ=MICRPROP_UNADJ <- NULL
   
   
@@ -418,8 +423,9 @@ modWFtree <- function(WFpopdat,
   ###################################################################################
   estdat <- check.estdata(esttype=esttype, pltcondf=pltcondx, 
                 cuniqueid=cuniqueid, condid=condid, 
-                treex=treex, seedx=seedx, estseed=estseed, sumunits=sumunits, 
-                landarea=landarea, ACI.filter=ACI.filter, pcfilter=pcfilter, 
+                treex=treex, seedx=seedx, estseed=estseed, woodland=woodland,
+				sumunits=sumunits, landarea=landarea, 
+				ACI.filter=ACI.filter, pcfilter=pcfilter, 
                 allin1=allin1, estround=estround, pseround=pseround, 
                 divideby=divideby, addtitle=addtitle, returntitle=returntitle, 
                 rawdata=rawdata, rawonly=rawonly, savedata=savedata, 
@@ -434,6 +440,7 @@ modWFtree <- function(WFpopdat,
   seedf <- estdat$seedf
   tuniqueid <- estdat$tuniqueid
   estseed <- estdat$estseed
+  woodland <- estdat$woodland
   sumunits <- estdat$sumunits
   landarea <- estdat$landarea
   allin1 <- estdat$allin1
@@ -465,8 +472,7 @@ modWFtree <- function(WFpopdat,
   rowcolinfo <- check.rowcol(gui=gui, esttype=esttype, treef=treef, seedf=seedf,
 	                condf=pltcondf, cuniqueid=cuniqueid, 
 	                tuniqueid=tuniqueid, estseed=estseed,
-	                rowvar=rowvar, rowvar.filter=rowvar.filter, 
-	                colvar=colvar, colvar.filter=colvar.filter, 
+	                rowvar=rowvar, colvar=colvar, 
 	                row.FIAname=row.FIAname, col.FIAname=col.FIAname,
  	                row.orderby=row.orderby, col.orderby=col.orderby, 
 	                row.add0=row.add0, col.add0=col.add0, 
@@ -750,14 +756,14 @@ domain = "TOTAL"
       setnames(tdomdat, estvar.name, estvar.name.micr)
     }
 
-yn = estvar.name.subp
-y2n = estvar.name.micr
-yd = pmeassubp.name
-y2d = pmeasmicr.name
-ysum = tdomdat
-dsum = pmeasprop
-uniqueid = cuniqueid
-domain = rowvar
+#yn = estvar.name.subp
+#y2n = estvar.name.micr
+#yd = pmeassubp.name
+#y2d = pmeasmicr.name
+#ysum = tdomdat
+#dsum = pmeasprop
+#uniqueid = cuniqueid
+#domain = rowvar
 
 
     unit_rowest <- Ratio2Size(yn = estvar.name.subp, 
